const int offPin = 7;    // The pin connected to the power OFF function

unsigned long nPowerOffTime;

void resetPowerOffTimer()
{
  // This function resets the time when CPU should be powered off
  // If there is activity on the robot, then call this function to 
  // reset the time to power off
  const int kInactivityPeriodForPowerOffSeconds = 120;  
  nPowerOffTime = millis() + (kInactivityPeriodForPowerOffSeconds * 1000);
  return;
}

void setup()
{
  // In Arduino, the "setup" function is called once when user program starts
  
  // Setup the "offPin" to be an output. Initial value is low.
  pinMode(offPin, OUTPUT);
  digitalWrite(offPin, LOW);

  resetPowerOffTimer();
  return;
}

void sendRemoteControlMsgToRobot()
{
  ...Send Wireless message to remote containing joystick and button values...
    
  if (...Joysticks or buttons have changed value...)
    resetPowerOffTimer();
}


void loop()
{
  // In an Arduino application, the loop function is called continuously. 
  // The user's application should do its work and return. Between calls
  // to to the "loop" function other housekeeping functions are performed.
  
  int nCurrTime = millis();
 
  {
    // Every 50 msec send a wireless message to robot with joystick values
    
    const int kTimeBetweenRCMessages = 50;
    static int nTimeForNextRemoteControlMessage = 0;
    if (nCurrTime >= nTimeForNextRemoteControlMessage)
    {
      nTimeForNextRemoteControlMessage = nCurrTime + kTimeBetweenRCMessages;
      sendRemoteControlMsgToRobot();
    }
  }

  // Check to see if CPU should be automatically powered off
  {
    if (nCurrTime >= nPowerOffTime)
      digitalWrite(offPin, HIGH);
  }
}
